@@ -8,8 +8,8 @@ import seaborn as sns
 import io
 import cv2
 #from gym_idsgame.envs.dao.idsgame_config import IdsGameConfig
-from gym_idsgame.envs.dao.game_config import GameConfig
-from gym_idsgame.envs.dao.game_state import GameState
+#from gym_idsgame.envs.dao.game_config import GameConfig
+#from gym_idsgame.envs.dao.game_state import GameState
 from gym_idsgame.envs.dao.node_type import NodeType
 #from gym_idsgame.envs.dao.network_config import NetworkConfig
 
@@ -28,7 +28,7 @@ from gym_idsgame.envs.dao.node_type import NodeType
 #         raise AssertionError("The max attack/defense value cannot be less than 1")
 
 
-def is_defense_id_legal(defense_id: int, game_config: GameConfig, state : GameState) -> bool:
+def is_defense_id_legal(defense_id: int, game_config, state) -> bool:
     """
     Check if a given defense is legal or not.
 
@@ -91,7 +91,7 @@ def is_node_attack_legal(target_node : int, attacker_pos : Union[int, int], netw
     return network_config.adjacency_matrix[attacker_adjacency_matrix_id][target_adjacency_matrix_id] == int(1)
 
 
-def is_node_defense_legal(target_node : int, network_config, state : GameState, max_value:int) -> bool:
+def is_node_defense_legal(target_node : int, network_config, state, max_value:int) -> bool:
     if (network_config.node_list[target_node] == NodeType.SERVER.value
             or network_config.node_list[target_node] == NodeType.DATA.value):
         if state.defense_det[target_node] < max_value:
@@ -128,7 +128,7 @@ def is_attack_legal(target_pos: Union[int, int], attacker_pos: Union[int, int],
     return network_config.adjacency_matrix[attacker_adjacency_matrix_id][target_adjacency_matrix_id] == int(1)
 
 
-def is_attack_id_legal(attack_id: int, game_config: GameConfig, attacker_pos: Union[int, int], game_state : GameState,
+def is_attack_id_legal(attack_id: int, game_config, attacker_pos: Union[int, int], game_state,
                        past_positions: List[int] = None, past_reconnaissance_activities: List = None) -> bool:
     """
     Check if a given attack is legal or not.
@@ -153,7 +153,7 @@ def is_attack_id_legal(attack_id: int, game_config: GameConfig, attacker_pos: Un
     return is_attack_legal(server_pos, attacker_pos, game_config.network_config, past_positions)
 
 
-def interpret_attack_action(action: int, game_config: GameConfig) -> Union[int, Union[int, int], int, bool]:
+def interpret_attack_action(action: int, game_config) -> Union[int, Union[int, int], int, bool]:
     """
     Utility method for interpreting the given attack action, converting it into server_id,pos,type
 
@@ -175,7 +175,7 @@ def interpret_attack_action(action: int, game_config: GameConfig) -> Union[int,
     #print("server:{},pos:{},a_type:{},rec:{}".format(server_id, server_pos, attack_type, reconnaissance))
     return server_id, server_pos, attack_type, reconnaissance
 
-def interpret_defense_action(action: int, game_config: GameConfig) -> Union[int, Union[int, int], int]:
+def interpret_defense_action(action: int, game_config) -> Union[int, Union[int, int], int]:
     """
     Utility method for interpreting the given action, converting it into server_id,pos,type
 
@@ -189,7 +189,7 @@ def interpret_defense_action(action: int, game_config: GameConfig) -> Union[int,
     return server_id, server_pos, defense_type
 
 
-def get_attack_action_id(server_id, attack_type, game_config: GameConfig):
+def get_attack_action_id(server_id, attack_type, game_config):
     """
     Gets the attack action id from a given server position, attack_type, and game config
 
@@ -205,7 +205,7 @@ def get_attack_action_id(server_id, attack_type, game_config: GameConfig):
     return action_id
 
 
-def get_defense_action_id(server_id, defense_type, game_config: GameConfig):
+def get_defense_action_id(server_id, defense_type, game_config):
     """
     Gets the defense action id from a given server position, defense_type, and game config
 
@@ -218,7 +218,7 @@ def get_defense_action_id(server_id, defense_type, game_config: GameConfig):
     return action_id
 
 
-def get_attack_type(action: int, game_config: GameConfig) -> int:
+def get_attack_type(action: int, game_config) -> int:
     """
     Utility method for getting the attack type of action-id
 
@@ -233,7 +233,7 @@ def get_attack_type(action: int, game_config: GameConfig) -> int:
     return attack_defense_type
 
 
-def get_defense_type(action: int, game_config: GameConfig) -> int:
+def get_defense_type(action: int, game_config) -> int:
     """
     Utility method for getting the defense type of action-id
 
@@ -316,7 +316,7 @@ def action_dist_hist(data: np.ndarray,
     return data
 
 
-def defense_score(game_sate : GameState, network_config, game_config : GameConfig):
+def defense_score(game_sate, network_config, game_config):
     total_min_def = 0
     for row in range(network_config.num_rows):
         min_def = float("inf")
